@@ -4,10 +4,17 @@ check<-function(fdata,mdata,fz,mz){
   stopifnot(all(fz%in%c(0,1)))
   stopifnot(all(mz%in%c(0,1)))
 
+  if (is.vector(fdata)) fdata<-matrix(fdata,ncol=1)
+  if (is.vector(mdata)) mdata<-matrix(mdata,ncol=1)
+
   fd0<-fdata[which(fz==0),]
   fd1<-fdata[which(fz==1),]
   md0<-mdata[which(mz==0),]
   md1<-mdata[which(mz==1),]
+  if (is.vector(fd0)) fd0<-matrix(fd0,length(fd0),1)
+  if (is.vector(md0)) md0<-matrix(md0,length(md0),1)
+  if (is.vector(fd1)) fd1<-matrix(fd1,length(fd1),1)
+  if (is.vector(md1)) md1<-matrix(md1,length(md1),1)
 
   sdf0<-apply(fd0,2,sd)
   sdf1<-apply(fd1,2,sd)
